// version: 2004-04-14
var _Debug = false;  // set this to false to turn debugging off
                     // and get rid of those annoying alert boxes.


// Define exception/error codes
var _NoError = 0;
var _GeneralException = 101;
var _ServerBusy = 102;
var _InvalidArgumentError = 201;
var _ElementCannotHaveChildren = 202;
var _ElementIsNotAnArray = 203;
var _NotInitialized = 301;
var _NotImplementedError = 401;
var _InvalidSetValue = 402;
var _ElementIsReadOnly = 403;
var _ElementIsWriteOnly = 404;
var _IncorrectDataType = 405;


// local variable definitions
var apiHandle = null;
var API = null;
var findAPITries = 0;


function doLMSInitialize(scoid)
{

 if (isAPIAvalaible()) {
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSInitialize was not successful.");
      return "false";
   }
    var temp ;
    temp = String(scoid);
     if (temp=="undefined") { temp =""}
     var result = api.LMSInitialize(temp);


   if (result.toString() != "true")
   {
   alert(result.toString())
      var err = ErrorHandler();
   }

   return result.toString();
   }
}

function doLMSFinish(indata)
{
if (isAPIAvalaible()) {
   var api = getAPIHandle();
   if (api == null)
   {
      //alert("Unable to locate the LMS's API Implementation.\nLMSFinish was not successful.");
      return "false";
   }
   else
   {
      // call the LMSFinish function that should be implemented by the API
      var result = api.LMSFinish("");
      if (result.toString() != "true")
      {
         var err = ErrorHandler();
      }

   }

   return result.toString();
  }
}

function doLMSGetValue(name)
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSGetValue was not successful.");
      return "";
   }
   else
   {
      var value = api.LMSGetValue(name);
      var errCode = api.LMSGetLastError().toString();
      if (errCode != _NoError)
      {
         // an error was encountered so display the error description
         var errDescription = api.LMSGetErrorString(errCode);
         alert("LMSGetValue("+name+") failed. \n"+ errDescription);
         return "";
      }
      else
      {
         
         return value.toString();
      }
   }
}

function doLMSSetValue(name, value)
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSSetValue was not successful.");
      return;
   }
   else
   {
      var result = api.LMSSetValue(name, value);
      if (result.toString() != "true")
      {
         var err = ErrorHandler();
      }
   }

   return;
}

function doLMSCommit()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSCommit was not successful.");
      return "false";
   }
   else
   {
      var result = api.LMSCommit("");
      if (result != "true")
      {
         var err = ErrorHandler();
      }
   }

   return result.toString();
}

function doLMSGetLastError()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSGetLastError was not successful.");
      //since we can't get the error code from the LMS, return a general error
      return _GeneralError;
   }

   return api.LMSGetLastError().toString();
}

function doLMSGetErrorString(errorCode)
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSGetErrorString was not successful.");
   }

   return api.LMSGetErrorString(errorCode).toString();
}

function doLMSGetDiagnostic(errorCode)
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSGetDiagnostic was not successful.");
   }

   return api.LMSGetDiagnostic(errorCode).toString();
}

function LMSIsInitialized()
{
   // there is no direct method for determining if the LMS API is initialized
   // for example an LMSIsInitialized function defined on the API so we'll try
   // a simple LMSGetValue and trap for the LMS Not Initialized Error

   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nLMSIsInitialized() failed.");
      return false;
   } else {
      var value = api.LMSGetValue("cmi.core.student_name");
      var errCode = api.LMSGetLastError().toString();
      if (errCode == _NotInitialized)
      {
         return false;
      }
      else
      {
         return true;
      }
   }
}

function ErrorHandler()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMS's API Implementation.\nCannot determine LMS error code.");
      return;
   }

   // check for errors caused by or from the LMS
   var errCode = api.LMSGetLastError().toString();
   if (errCode != _NoError)
   {
      // an error was encountered so display the error description
      var errDescription = api.LMSGetErrorString(errCode);

      if (_Debug == true)
      {
         errDescription += "\n";
         errDescription += api.LMSGetDiagnostic(null);
         // by passing null to LMSGetDiagnostic, we get any available diagnostics
         // on the previous error.
      }

      alert(errDescription);
   }

   return errCode;
}

function getAPIHandle()
{
   if (apiHandle == null)
   {
      apiHandle = getAPI();
   }

   return apiHandle;
}


function findAPI(win)
{
   while ((win.API == null) && (win.parent != null) && (win.parent != win))
   {
      findAPITries++;
      // Note: 7 is an arbitrary number, but should be more than sufficient
      if (findAPITries > 7) 
      {
         //alert("Error finding API -- too deeply nested.");
         return null;
      }
      
      win = win.parent;

   }
   return win.API;
}



function getAPI()
{
   var theAPI = findAPI(window.top);
   if ((theAPI == null) && (window.top.opener != null) && (typeof(window.top.opener) != "undefined"))
   {
      theAPI = findAPI(window.top.opener);
   }
   if (theAPI == null)
   {
    //  alert("Unable to find an API adapter");
   }
   return theAPI
}

function isAPIAvalaible()
{
   // there is no direct method for determining if the LMS API is initialized
   // for example an LMSIsInitialized function defined on the API so we'll try
   // a simple LMSGetValue and trap for the LMS Not Initialized Error


/////  TEMPORARY /////
/////////////////////////////
_usescorm = true;
/////////////////////////////

if (!_usescorm) {
 	return false
 } else {
   var api = getAPIHandle();
   if (api == null)
   {
      return false;
   }
   else
   {
         return true;
   }
   
 }
}


function InitializeSco(ScoIdentifier) {
// Brukes i utvidet API-sttte
	if (isAPIAvalaible() || 1) {
			var result = doLMSInitialize(ScoIdentifier)
			var retval 
			if (result=="true") { retval = "0"} else {retval="1" }
			
			timeOutId = setTimeout("shockmessage('navigation','ReturnDataFromAPI "+retval +"#newsco#" + ""+ "')",100)
	}
	
}

function getLMSValues(usescorm) {
	var ok = false
	if (isAPIAvalaible()) {
		// har funnet API-adapter
		var result = doLMSInitialize()
		if (result =="true") {
			// initalisering har gtt bra, hent oppstartsdata
			ok = true
			result = doLMSGetValue("cmi.launch_data");
			sendLMSValuesToFlash("SCORM1", "SCORM1" + result);
			//returnApiData(result);
		}
	}
	
	if (!ok) {
		 // Har ikke funnet API-adapter	
		 sendLMSValuesToFlash("AICC", unescape(top.document.location.href.replace(/\\/g,"\/")));
		 //returnApiData(unescape(top.document.location.href.replace(/\\/g,"\/")));
	}

}

function getapidata(usecommentsfield) {
	// Henter data fra LMS-et og sende det til navigasjonslaget
	var result = ""
	var delim = "##"
	result = result + doLMSGetValue("cmi.core.student_name") + delim
	result = result + doLMSGetValue("cmi.core.lesson_location") + delim
	result = result + doLMSGetValue("cmi.core.score.raw") + delim
	result = result + doLMSGetValue("cmi.core.lesson_status") + delim
	var temp = doLMSGetValue("cmi.suspend_data")
	result = result + temp + delim
	// sjekk om man skal bruke commentsfield
	if (usecommentsfield=="1") {
		result = result + doLMSGetValue("cmi.comments") +delim
	}

	//alert("call returnApiData with result: " + result);
	returnApiData(result);
	//timeOutId = setTimeout("shockmessage('navigation','ReturnDataFromAPI 0"+delim + "getparam"+ delim + result + "')",100)

}

function setapidata(indata) {
	// Sender data til LMS-et 
	//alert("setapidata: " + indata)
	  ParameterList = indata.split("##");
	  var ok = doLMSSetValue("cmi.core.lesson_status", ParameterList[0])
	  //ok = doLMSSetValue("cmi.core.session_time", ParameterList[1])
	  ok = doLMSSetValue("cmi.core.session_time", "00:00:00");
	  ok = doLMSSetValue("cmi.core.lesson_location", ParameterList[2])
	  ok = doLMSSetValue("cmi.core.score.raw", ParameterList[3])
	  ok = doLMSSetValue("cmi.suspend_data", ParameterList[4])
	  if (ParameterList.length == 6) { ok = doLMSSetValue("cmi.comments", ParameterList[5]) }	
	  doLMSCommit()
	//timeOutId = setTimeout("shockmessage('navigation','ReturnDataFromAPI 0#" + "putparam#" + ""+ "')",100)

}

